==> charlatan_0.5.1.tar.gz: charlatan/R/jobs-provider-pl_PL.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/pl_PL/__init__.py

job_formats_pl_pl <- c(
  "Agent celny",
  "Agent firmy inwestycyjnej",
  "Agent literacki",
  "Agent ubezpieczeniowy",
  "Agronom",
  "Aktor",
  "Aktor dzieci\u0119cy",
  "Aktor g\u0142osowy",
  "Aktuariusz",
  "Animator kultury",
  "Ankieter",
  "Antykwariusz",
  "Arborysta",
  "Archeolog",
  "Architekt krajobrazu",
  "Architekt wn\u0119trz",
  "Archiwista",
  "Artysta-rezydent",
  "Astronom",
  "Audytor efektywno\u015bci energetycznej",
  "Babcia klozetowa",
  "Bankowiec",
  "Barista",
  "Barman",
  "Bibliotekarz",
  "Bibliotekarz dyplomowany",
  "Bieg\u0142y rewident",
  "Brakarz",
  "Broker",
  "Broker informacji",
  "Broker ubezpieczeniowy",
  "Certyfikator energetyczny",
  "Charakteryzator",
  "Detektyw",
  "Deweloper budowlany",
  "Doker",
  "Doradca finansowy",
  "Doradca inwestycyjny",
  "Doradca podatkowy w Polsce",
  "Doradca ubezpieczeniowy",
  "Drwal",
  "Dubler",
  "Dyplomata",
  "Dyrektor artystyczny",
  "Dyrektor finansowy",
  "Dyrektor kreatywny",
  "Dziennikarz",
  "D\u017cokej",
  "Ebenista",
  "Ekonomista",
  "Ekwilibrystyka",
  "Elektromonter pomiar\u00f3w",
  "Ergonomista",
  "Fasowacz",
  "Finansista",
  "Fotoreporter",
  "Geodeta",
  "Geolog",
  "G\u0142\u00f3wny ksi\u0119gowy",
  "Grabarz",
  "Handlarz",
  "Hostessa",
  "Hutnik",
  "Hycel",
  "Hydraulik",
  "Iluzjonista",
  "Inscenizator",
  "Instruktor",
  "Integrator automatyki",
  "Intendent",
  "In\u017cynier",
  "In\u017cynier budownictwa",
  "Kasjer biletowy",
  "Katecheta",
  "Kawalkator",
  "Kawiarka",
  "Kelner",
  "Kierowca",
  "Kiper",
  "Klechdarz",
  "Konferansjer",
  "Koniarze",
  "Konserwator zabytk\u00f3w",
  "Konsjer\u017c",
  "Konstruktor",
  "Konsultant",
  "Konsultant \u015blubny",
  "Kontroler bilet\u00f3w",
  "Kornak",
  "Kosmonauta",
  "Kostiumograf",
  "Kosztorysant",
  "Kowboj",
  "Krojczy",
  "Krupier",
  "Ksi\u0105dz",
  "Ksi\u0119gowy",
  "Kuk",
  "Kupiec",
  "Kurator s\u0105dowy",
  "Kurator sztuki",
  "Kurier",
  "Kurier rowerowy",
  "Lalkarz",
  "Le\u015bniczy",
  "Liczmen",
  "Likwidator szk\u00f3d",
  "Listonosz",
  "\u0141\u0105cznik",
  "Makler gie\u0142d towarowych",
  "Makler morski",
  "Makler nadzoruj\u0105cy",
  "Makler papier\u00f3w warto\u015bciowych",
  "Marketingowiec",
  "Marynarz",
  "Masztalerz",
  "Mened\u017cer kultury",
  "Meteorolog",
  "Mim",
  "Model",
  "Modelka du\u017cych rozmiar\u00f3w",
  "Motorniczy",
  "Nadle\u015bniczy",
  "Nauczyciel",
  "Nauczyciel akademicki",
  "Naukowiec",
  "Niania",
  "Oceanonauta",
  "Ochroniarz",
  "Pakowacz",
  "Palacz",
  "Perfumiarz",
  "Pisarz",
  "Plastyk",
  "Podle\u015bniczy",
  "Poganiacz",
  "Pokoj\u00f3wka",
  "Politolog",
  "Polityk",
  "Portier",
  "Po\u015brednik finansowy",
  "Po\u015brednik ubezpieczeniowy",
  "Po\u015brednik w obrocie nieruchomo\u015bciami",
  "Pracownicy uczelni w Polsce",
  "Pracownik socjalny",
  "Prezenter",
  "Producent wykonawczy",
  "Projektant gier komputerowych",
  "Przedstawiciel handlowy",
  "Przewodnik turystyczny",
  "Psiarz",
  "Psycholog",
  "Pucybut",
  "Rachmistrz",
  "Ratownik",
  "Ratownik przedmedyczny",
  "Redaktor",
  "Redaktor merytoryczny",
  "Redaktor naukowy",
  "Redaktor techniczny",
  "Rekwizytor",
  "Reporter wojenny",
  "Re\u017cyser",
  "Robotnik",
  "Rolnik",
  "Rybak",
  "Rzecznik prasowy",
  "Rzeczoznawca",
  "Rzeczoznawca budowlany",
  "Rzeczoznawca maj\u0105tkowy",
  "Rzeczoznawca samochodowy",
  "Salowa",
  "Satyryk",
  "Scenarzysta",
  "Scenograf",
  "S\u0142u\u017c\u0105cy",
  "Sprz\u0105tacz",
  "Sprzedawca",
  "Stajenny",
  "Stra\u017cak",
  "Sufler",
  "Supermodelka",
  "Syndyk",
  "Syndyk licencjonowany",
  "Szatniarz",
  "Szczuro\u0142ap",
  "Szlifierz",
  "Sztygar",
  "Taks\u00f3wkarz",
  "Technik awionik",
  "Technik budownictwa",
  "Technik elektronik",
  "Technik handlowiec",
  "Technik kelner",
  "Technik mechanik",
  "Technik mechanik lotniczy",
  "Technik mechanik okr\u0119towy",
  "Technik nawigator morski",
  "Technik ochrony \u015brodowiska",
  "Technik technologii drewna",
  "Technik weterynarii",
  "Technik \u017cywienia i gospodarstwa domowego",
  "Teksturator",
  "Terapeuta",
  "Terminolog",
  "T\u0142umacz",
  "T\u0142umacz literacki",
  "T\u0142umacz przysi\u0119g\u0142y",
  "Tokarz",
  "Trener",
  "Trener personalny",
  "Urbanista",
  "Lekarz weterynarii",
  "Wydawca",
  "Zarz\u0105dca nieruchomo\u015bci",
  "Zoopsycholog",
  "\u017bo\u0142nierz",
  "\u017bongler"
)

==> charlatan_0.6.1.tar.gz: charlatan/R/jobs-provider-pl_PL.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/pl_PL/__init__.py

job_formats_pl_pl <- c(
  "Agent celny",
  "Agent firmy inwestycyjnej",
  "Agent literacki",
  "Agent ubezpieczeniowy",
  "Agronom",
  "Aktor",
  "Aktor dzieci\u0119cy",
  "Aktor g\u0142osowy",
  "Aktuariusz",
  "Animator kultury",
  "Ankieter",
  "Antykwariusz",
  "Arborysta",
  "Archeolog",
  "Architekt krajobrazu",
  "Architekt wn\u0119trz",
  "Archiwista",
  "Artysta-rezydent",
  "Astronom",
  "Audytor efektywno\u015bci energetycznej",
  "Babcia klozetowa",
  "Bankowiec",
  "Barista",
  "Barman",
  "Bibliotekarz",
  "Bibliotekarz dyplomowany",
  "Bieg\u0142y rewident",
  "Brakarz",
  "Broker",
  "Broker informacji",
  "Broker ubezpieczeniowy",
  "Certyfikator energetyczny",
  "Charakteryzator",
  "Detektyw",
  "Deweloper budowlany",
  "Doker",
  "Doradca finansowy",
  "Doradca inwestycyjny",
  "Doradca podatkowy w Polsce",
  "Doradca ubezpieczeniowy",
  "Drwal",
  "Dubler",
  "Dyplomata",
  "Dyrektor artystyczny",
  "Dyrektor finansowy",
  "Dyrektor kreatywny",
  "Dziennikarz",
  "D\u017cokej",
  "Ebenista",
  "Ekonomista",
  "Ekwilibrystyka",
  "Elektromonter pomiar\u00f3w",
  "Ergonomista",
  "Fasowacz",
  "Finansista",
  "Fotoreporter",
  "Geodeta",
  "Geolog",
  "G\u0142\u00f3wny ksi\u0119gowy",
  "Grabarz",
  "Handlarz",
  "Hostessa",
  "Hutnik",
  "Hycel",
  "Hydraulik",
  "Iluzjonista",
  "Inscenizator",
  "Instruktor",
  "Integrator automatyki",
  "Intendent",
  "In\u017cynier",
  "In\u017cynier budownictwa",
  "Kasjer biletowy",
  "Katecheta",
  "Kawalkator",
  "Kawiarka",
  "Kelner",
  "Kierowca",
  "Kiper",
  "Klechdarz",
  "Konferansjer",
  "Koniarze",
  "Konserwator zabytk\u00f3w",
  "Konsjer\u017c",
  "Konstruktor",
  "Konsultant",
  "Konsultant \u015blubny",
  "Kontroler bilet\u00f3w",
  "Kornak",
  "Kosmonauta",
  "Kostiumograf",
  "Kosztorysant",
  "Kowboj",
  "Krojczy",
  "Krupier",
  "Ksi\u0105dz",
  "Ksi\u0119gowy",
  "Kuk",
  "Kupiec",
  "Kurator s\u0105dowy",
  "Kurator sztuki",
  "Kurier",
  "Kurier rowerowy",
  "Lalkarz",
  "Le\u015bniczy",
  "Liczmen",
  "Likwidator szk\u00f3d",
  "Listonosz",
  "\u0141\u0105cznik",
  "Makler gie\u0142d towarowych",
  "Makler morski",
  "Makler nadzoruj\u0105cy",
  "Makler papier\u00f3w warto\u015bciowych",
  "Marketingowiec",
  "Marynarz",
  "Masztalerz",
  "Mened\u017cer kultury",
  "Meteorolog",
  "Mim",
  "Model",
  "Modelka du\u017cych rozmiar\u00f3w",
  "Motorniczy",
  "Nadle\u015bniczy",
  "Nauczyciel",
  "Nauczyciel akademicki",
  "Naukowiec",
  "Niania",
  "Oceanonauta",
  "Ochroniarz",
  "Pakowacz",
  "Palacz",
  "Perfumiarz",
  "Pisarz",
  "Plastyk",
  "Podle\u015bniczy",
  "Poganiacz",
  "Pokoj\u00f3wka",
  "Politolog",
  "Polityk",
  "Portier",
  "Po\u015brednik finansowy",
  "Po\u015brednik ubezpieczeniowy",
  "Po\u015brednik w obrocie nieruchomo\u015bciami",
  "Pracownicy uczelni w Polsce",
  "Pracownik socjalny",
  "Prezenter",
  "Producent wykonawczy",
  "Projektant gier komputerowych",
  "Przedstawiciel handlowy",
  "Przewodnik turystyczny",
  "Psiarz",
  "Psycholog",
  "Pucybut",
  "Rachmistrz",
  "Ratownik",
  "Ratownik przedmedyczny",
  "Redaktor",
  "Redaktor merytoryczny",
  "Redaktor naukowy",
  "Redaktor techniczny",
  "Rekwizytor",
  "Reporter wojenny",
  "Re\u017cyser",
  "Robotnik",
  "Rolnik",
  "Rybak",
  "Rzecznik prasowy",
  "Rzeczoznawca",
  "Rzeczoznawca budowlany",
  "Rzeczoznawca maj\u0105tkowy",
  "Rzeczoznawca samochodowy",
  "Salowa",
  "Satyryk",
  "Scenarzysta",
  "Scenograf",
  "S\u0142u\u017c\u0105cy",
  "Sprz\u0105tacz",
  "Sprzedawca",
  "Stajenny",
  "Stra\u017cak",
  "Sufler",
  "Supermodelka",
  "Syndyk",
  "Syndyk licencjonowany",
  "Szatniarz",
  "Szczuro\u0142ap",
  "Szlifierz",
  "Sztygar",
  "Taks\u00f3wkarz",
  "Technik awionik",
  "Technik budownictwa",
  "Technik elektronik",
  "Technik handlowiec",
  "Technik kelner",
  "Technik mechanik",
  "Technik mechanik lotniczy",
  "Technik mechanik okr\u0119towy",
  "Technik nawigator morski",
  "Technik ochrony \u015brodowiska",
  "Technik technologii drewna",
  "Technik weterynarii",
  "Technik \u017cywienia i gospodarstwa domowego",
  "Teksturator",
  "Terapeuta",
  "Terminolog",
  "T\u0142umacz",
  "T\u0142umacz literacki",
  "T\u0142umacz przysi\u0119g\u0142y",
  "Tokarz",
  "Trener",
  "Trener personalny",
  "Urbanista",
  "Lekarz weterynarii",
  "Wydawca",
  "Zarz\u0105dca nieruchomo\u015bci",
  "Zoopsycholog",
  "\u017bo\u0142nierz",
  "\u017bongler"
)

#' Job provider for Poland
#'
#' @inherit JobProvider description details return
#' @family pl
#' @family PL
#' @export
#' @examples
#' x <- JobProvider_pl_PL$new()
#' x$render()
JobProvider_pl_PL <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_pl_PL",
  private = list(
    locale_ = "pl_PL",
    formats = job_formats_pl_pl
  )
)
